#!/usr/bin/ksh

# -----------------------------------------------------------------------
# Checks whether a given service is being advertised by SLP on a given 
# host ip address. The  script looks for slp_query and slp_tool utilities
# in predefined locations. It first attempt to use slp_query and if not
# found, slp_tool. If both not found then result=notfound being returned.
#
# @param
#	ipaddress=<host ip>
#	service=<service name>
#
# @return
#	result=notfound
#			No SLP query utility found.
#
#	result=fail
#			SLP query could not list the given service
#
#	result=success
#			SLP query successfully list the given service
#
# ------------------------------------------------------------------------

ipaddress="$(echo $1 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
service="$(echo $2 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"

slp_query=""
slp_tool=""

# --------------------------------------------------
# There two different utilities shipped with agent:
# 1) slp_query
# 2) slp_tool
#
# But they have a same purpose -- locate SLP service.
# We attempt to search in some predefined locations
# (hard coded for now). We first try to use slp_query
# and if not found then slp_tool
# --------------------------------------------------

if [ -e /opt/ibm/icc/bin/slptool ]; then
        slp_tool="/opt/ibm/icc/bin/slptool"
fi

if [ -e /opt/ibm/icc/cimom/bin/slptool ]; then
        slp_tool="/opt/ibm/icc/cimom/bin/slptool"
fi

if [ -e /usr/bin/slp_query ]; then
        slp_query="/usr/bin/slp_query"
fi

if [ -e /opt/ibm/icc/bin/slp_query ]; then
        slp_query="/opt/ibm/icc/bin/slp_query"
fi

if [ $slp_query"X" = "X" ]; then

		# ------------------------------
        # slp_query not available - use
        # slp_tool instead
        # ------------------------------
        
        if [ $slp_tool"X" = "X" ]; then
                echo "result=notfound";
                exit 0;
        fi

        output="$($slp_tool -u $ipaddress findsrvs $service | grep $service)"
        output_no_spaces=`echo $output | sed -e 's/^ *//' -e 's/ *$//'`

else

        output="$($slp_query --address=$ipaddress --type=$service | grep $service)"
        output_no_spaces=`echo $output | sed -e 's/^ *//' -e 's/ *$//'`

fi


# --------------------------------------------------
# Process the output from SLP command and search for
# the service name to appear
# --------------------------------------------------

case "$output_no_spaces" in
    *$service* ) echo "result=success"; exit 0;;
    * ) echo "result=fail";;
esac
