#! /bin/bash

# -----------------------------------------------------------------------
# Retrieves the access state of the MEP.
#
# @param
#	user=<DS user>
#	password=<DS password>
#	ipaddress=<ip of mep>
#	type=<MEP type>
#
# @return
#	result=success
#			Overall operation succeed
#	
#	state=<access state>
#			Valid for a success result. Indicates the access state of 
#			the MEP
#
#	result=notfound
#			In case MEP was not found in Systems Director
#
#	result=fail_retrieve
#		In case error occurred when attempting to retrieve the MEP
#		from Systems Director
#
#	result=fail_auth
#			Failed to invoke smcli with DS credentials supplied
#
#	result=fail
#		In case general error occurred when attempting to retrieve the
#		access state of the MEP.
#
# ------------------------------------------------------------------------

user="$(echo $1 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
password="$(echo $2 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
ipaddress="$(echo $3 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
mep_type="$(echo $4 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"

# -------------------------------------------------------------------------
# At first just check that command works (i/o redirect -- we do not
# want to see its output)
# -------------------------------------------------------------------------
smcli -user $user -pw $password lssys -t $mep_type -i $ipaddress -A AccessState  > /dev/null 2>&1
RC=$?

if [ "$RC" = "3" ]; then
        echo "result=fail_auth"
        exit 0;
fi

if [ "$RC" = "20" ]; then
        echo "result=notfound"
        exit 0;
fi

if [ "$RC" != "0" ]; then
        echo "result=fail_retrieve"
        exit 0;
fi

# Trying again
output="$(smcli -user $user -pw $password lssys -t $mep_type -i $ipaddress -A AccessState)"
# -------------------------------------------------------------------------
# Due to a bug in smcli lssys it can return RC=0 but without any data
# (empty line)
# -------------------------------------------------------------------------
if [ "x$output" = "x" ]; then
	echo "result=notfound"
	exit 0;
fi

# Remove trailing carriage return for awk to properly work
output_no_spaces=${output/ /}
state="$(echo $output_no_spaces | awk '{ {split($1, split_result, ":")} {print split_result[2]} }')"
RC=$?
if [ "$RC" != "0" ]; then
        echo "result=fail"
        exit 0;
fi

state_no_spaces=${state/ /}
echo "result=success,state=$state_no_spaces"
