@echo off

rem -----------------------------------------------------------------------
rem Reports whether MEP is CAS.
rem
rem @param
rem user=<DS user>
rem password=<DS password>
rem	ipaddress=<ip of mep>
rem	type=<MEP type>
rem
rem @return
rem	result=success
rem			Overall operation succeed
rem
rem	is_cas={true, false}
rem			Relevant for a success result only. Indicates whether the MEP
rem			CAS or not.
rem
rem	result=notfound
rem			In case MEP was not found in Systems Director
rem
rem result=fail_auth
rem		Failed to invoke smcli with DS credentials supplied.
rem
rem	result=fail
rem		In case general error occurred when attempting to check whether the
rem		MEP is CAS or not.
rem
rem ------------------------------------------------------------------------


rem ---------------------------------------------------------
rem Seems that '=' performs already as a delimeter between 
rem arguments passed
rem ---------------------------------------------------------

set user=%2
set password=%4
set ipaddress=%6
set mep_type=%8

rem ------------------------------------------------------------------------
rem At first just check that command works (i/o redirect -- we do not
rem want to see its output)
rem -------------------------------------------------------------------------

smcli -user %user% -pw %password% lssys -t %mep_type% -i %ipaddress% -A Protocols  >NUL 2>NUL

if %ERRORLEVEL% equ 20 (
        echo result=notfound
        exit /b 0
)

if %ERRORLEVEL% equ 3 (
        echo result=fail_auth
        exit /b 0
)

if errorlevel 1 (
        echo result=fail
        exit /b 0
)

rem -------------------------------------------------------------------------
rem Due to a bug in smcli lssys it can return RC=0 but without any data
rem (empty line)
rem -------------------------------------------------------------------------
for /f "tokens=*" %%a in ('smcli -user %user% -pw %password% lssys -t %mep_type% -i %ipaddress% -A Protocols') do (
    GOTO CONTINUE
)

echo result=notfound
exit /b 0

:CONTINUE

rem Trying again
set lssys_cas_command=smcli -user %user% -pw %password% lssys -t %mep_type% -i %ipaddress% -A Protocols ^| find "CAS"

for /f "tokens=*" %%a in ('"call %lssys_cas_command%"') do (
    GOTO SUCCSESS
)

:FAIL
echo result=success,is_cas=false
GOTO FINAL

:SUCCSESS
echo result=success,is_cas=true

:FINAL
exit /b 0
	
